pub struct FixOpts {
allow_dirty: bool,
allow_staged: bool,
}Expand description
Options forwarded verbatim to cargo fix when --fix is passed.
These are ignored when running cargo check.
Fields
allow_dirty: boolDon’t require a clean git working directory when running --fix.
allow_staged: boolDon’t require a staged git index when running --fix.
Implementations